import {
  ExceptionOptionType as __ExceptionOptionType,
  LazyJsonString as __LazyJsonString,
} from "@smithy/smithy-client";
import { RekognitionServiceException as __BaseException } from "./RekognitionServiceException";
export declare class AccessDeniedException extends __BaseException {
  readonly name: "AccessDeniedException";
  readonly $fault: "client";
  Message?: string;
  Code?: string;
  Logref?: string;
  constructor(
    opts: __ExceptionOptionType<AccessDeniedException, __BaseException>
  );
}
export interface AgeRange {
  Low?: number;
  High?: number;
}
export interface S3Object {
  Bucket?: string;
  Name?: string;
  Version?: string;
}
export interface GroundTruthManifest {
  S3Object?: S3Object;
}
export interface Asset {
  GroundTruthManifest?: GroundTruthManifest;
}
export interface AssociatedFace {
  FaceId?: string;
}
export interface AssociateFacesRequest {
  CollectionId: string | undefined;
  UserId: string | undefined;
  FaceIds: string[] | undefined;
  UserMatchThreshold?: number;
  ClientRequestToken?: string;
}
export declare const UnsuccessfulFaceAssociationReason: {
  readonly ASSOCIATED_TO_A_DIFFERENT_USER: "ASSOCIATED_TO_A_DIFFERENT_USER";
  readonly FACE_NOT_FOUND: "FACE_NOT_FOUND";
  readonly LOW_MATCH_CONFIDENCE: "LOW_MATCH_CONFIDENCE";
};
export type UnsuccessfulFaceAssociationReason =
  (typeof UnsuccessfulFaceAssociationReason)[keyof typeof UnsuccessfulFaceAssociationReason];
export interface UnsuccessfulFaceAssociation {
  FaceId?: string;
  UserId?: string;
  Confidence?: number;
  Reasons?: UnsuccessfulFaceAssociationReason[];
}
export declare const UserStatus: {
  readonly ACTIVE: "ACTIVE";
  readonly CREATED: "CREATED";
  readonly CREATING: "CREATING";
  readonly UPDATING: "UPDATING";
};
export type UserStatus = (typeof UserStatus)[keyof typeof UserStatus];
export interface AssociateFacesResponse {
  AssociatedFaces?: AssociatedFace[];
  UnsuccessfulFaceAssociations?: UnsuccessfulFaceAssociation[];
  UserStatus?: UserStatus;
}
export declare class ConflictException extends __BaseException {
  readonly name: "ConflictException";
  readonly $fault: "client";
  Message?: string;
  Code?: string;
  Logref?: string;
  constructor(opts: __ExceptionOptionType<ConflictException, __BaseException>);
}
export declare class IdempotentParameterMismatchException extends __BaseException {
  readonly name: "IdempotentParameterMismatchException";
  readonly $fault: "client";
  Message?: string;
  Code?: string;
  Logref?: string;
  constructor(
    opts: __ExceptionOptionType<
      IdempotentParameterMismatchException,
      __BaseException
    >
  );
}
export declare class InternalServerError extends __BaseException {
  readonly name: "InternalServerError";
  readonly $fault: "server";
  Message?: string;
  Code?: string;
  Logref?: string;
  constructor(
    opts: __ExceptionOptionType<InternalServerError, __BaseException>
  );
}
export declare class InvalidParameterException extends __BaseException {
  readonly name: "InvalidParameterException";
  readonly $fault: "client";
  Message?: string;
  Code?: string;
  Logref?: string;
  constructor(
    opts: __ExceptionOptionType<InvalidParameterException, __BaseException>
  );
}
export declare class ProvisionedThroughputExceededException extends __BaseException {
  readonly name: "ProvisionedThroughputExceededException";
  readonly $fault: "client";
  Message?: string;
  Code?: string;
  Logref?: string;
  constructor(
    opts: __ExceptionOptionType<
      ProvisionedThroughputExceededException,
      __BaseException
    >
  );
}
export declare class ResourceNotFoundException extends __BaseException {
  readonly name: "ResourceNotFoundException";
  readonly $fault: "client";
  Message?: string;
  Code?: string;
  Logref?: string;
  constructor(
    opts: __ExceptionOptionType<ResourceNotFoundException, __BaseException>
  );
}
export declare class ServiceQuotaExceededException extends __BaseException {
  readonly name: "ServiceQuotaExceededException";
  readonly $fault: "client";
  Message?: string;
  Code?: string;
  Logref?: string;
  constructor(
    opts: __ExceptionOptionType<ServiceQuotaExceededException, __BaseException>
  );
}
export declare class ThrottlingException extends __BaseException {
  readonly name: "ThrottlingException";
  readonly $fault: "server";
  Message?: string;
  Code?: string;
  Logref?: string;
  constructor(
    opts: __ExceptionOptionType<ThrottlingException, __BaseException>
  );
}
export declare const Attribute: {
  readonly AGE_RANGE: "AGE_RANGE";
  readonly ALL: "ALL";
  readonly BEARD: "BEARD";
  readonly DEFAULT: "DEFAULT";
  readonly EMOTIONS: "EMOTIONS";
  readonly EYEGLASSES: "EYEGLASSES";
  readonly EYES_OPEN: "EYES_OPEN";
  readonly EYE_DIRECTION: "EYE_DIRECTION";
  readonly FACE_OCCLUDED: "FACE_OCCLUDED";
  readonly GENDER: "GENDER";
  readonly MOUTH_OPEN: "MOUTH_OPEN";
  readonly MUSTACHE: "MUSTACHE";
  readonly SMILE: "SMILE";
  readonly SUNGLASSES: "SUNGLASSES";
};
export type Attribute = (typeof Attribute)[keyof typeof Attribute];
export interface AudioMetadata {
  Codec?: string;
  DurationMillis?: number;
  SampleRate?: number;
  NumberOfChannels?: number;
}
export interface BoundingBox {
  Width?: number;
  Height?: number;
  Left?: number;
  Top?: number;
}
export interface AuditImage {
  Bytes?: Uint8Array;
  S3Object?: S3Object;
  BoundingBox?: BoundingBox;
}
export interface Beard {
  Value?: boolean;
  Confidence?: number;
}
export interface BlackFrame {
  MaxPixelThreshold?: number;
  MinCoveragePercentage?: number;
}
export declare const BodyPart: {
  readonly FACE: "FACE";
  readonly HEAD: "HEAD";
  readonly LEFT_HAND: "LEFT_HAND";
  readonly RIGHT_HAND: "RIGHT_HAND";
};
export type BodyPart = (typeof BodyPart)[keyof typeof BodyPart];
export interface CoversBodyPart {
  Confidence?: number;
  Value?: boolean;
}
export declare const ProtectiveEquipmentType: {
  readonly FACE_COVER: "FACE_COVER";
  readonly HAND_COVER: "HAND_COVER";
  readonly HEAD_COVER: "HEAD_COVER";
};
export type ProtectiveEquipmentType =
  (typeof ProtectiveEquipmentType)[keyof typeof ProtectiveEquipmentType];
export interface EquipmentDetection {
  BoundingBox?: BoundingBox;
  Confidence?: number;
  Type?: ProtectiveEquipmentType;
  CoversBodyPart?: CoversBodyPart;
}
export interface ProtectiveEquipmentBodyPart {
  Name?: BodyPart;
  Confidence?: number;
  EquipmentDetections?: EquipmentDetection[];
}
export declare const EmotionName: {
  readonly ANGRY: "ANGRY";
  readonly CALM: "CALM";
  readonly CONFUSED: "CONFUSED";
  readonly DISGUSTED: "DISGUSTED";
  readonly FEAR: "FEAR";
  readonly HAPPY: "HAPPY";
  readonly SAD: "SAD";
  readonly SURPRISED: "SURPRISED";
  readonly UNKNOWN: "UNKNOWN";
};
export type EmotionName = (typeof EmotionName)[keyof typeof EmotionName];
export interface Emotion {
  Type?: EmotionName;
  Confidence?: number;
}
export declare const LandmarkType: {
  readonly chinBottom: "chinBottom";
  readonly eyeLeft: "eyeLeft";
  readonly eyeRight: "eyeRight";
  readonly leftEyeBrowLeft: "leftEyeBrowLeft";
  readonly leftEyeBrowRight: "leftEyeBrowRight";
  readonly leftEyeBrowUp: "leftEyeBrowUp";
  readonly leftEyeDown: "leftEyeDown";
  readonly leftEyeLeft: "leftEyeLeft";
  readonly leftEyeRight: "leftEyeRight";
  readonly leftEyeUp: "leftEyeUp";
  readonly leftPupil: "leftPupil";
  readonly midJawlineLeft: "midJawlineLeft";
  readonly midJawlineRight: "midJawlineRight";
  readonly mouthDown: "mouthDown";
  readonly mouthLeft: "mouthLeft";
  readonly mouthRight: "mouthRight";
  readonly mouthUp: "mouthUp";
  readonly nose: "nose";
  readonly noseLeft: "noseLeft";
  readonly noseRight: "noseRight";
  readonly rightEyeBrowLeft: "rightEyeBrowLeft";
  readonly rightEyeBrowRight: "rightEyeBrowRight";
  readonly rightEyeBrowUp: "rightEyeBrowUp";
  readonly rightEyeDown: "rightEyeDown";
  readonly rightEyeLeft: "rightEyeLeft";
  readonly rightEyeRight: "rightEyeRight";
  readonly rightEyeUp: "rightEyeUp";
  readonly rightPupil: "rightPupil";
  readonly upperJawlineLeft: "upperJawlineLeft";
  readonly upperJawlineRight: "upperJawlineRight";
};
export type LandmarkType = (typeof LandmarkType)[keyof typeof LandmarkType];
export interface Landmark {
  Type?: LandmarkType;
  X?: number;
  Y?: number;
}
export interface Pose {
  Roll?: number;
  Yaw?: number;
  Pitch?: number;
}
export interface ImageQuality {
  Brightness?: number;
  Sharpness?: number;
}
export interface Smile {
  Value?: boolean;
  Confidence?: number;
}
export interface ComparedFace {
  BoundingBox?: BoundingBox;
  Confidence?: number;
  Landmarks?: Landmark[];
  Pose?: Pose;
  Quality?: ImageQuality;
  Emotions?: Emotion[];
  Smile?: Smile;
}
export declare const KnownGenderType: {
  readonly Female: "Female";
  readonly Male: "Male";
  readonly Nonbinary: "Nonbinary";
  readonly Unlisted: "Unlisted";
};
export type KnownGenderType =
  (typeof KnownGenderType)[keyof typeof KnownGenderType];
export interface KnownGender {
  Type?: KnownGenderType;
}
export interface Celebrity {
  Urls?: string[];
  Name?: string;
  Id?: string;
  Face?: ComparedFace;
  MatchConfidence?: number;
  KnownGender?: KnownGender;
}
export interface EyeDirection {
  Yaw?: number;
  Pitch?: number;
  Confidence?: number;
}
export interface Eyeglasses {
  Value?: boolean;
  Confidence?: number;
}
export interface EyeOpen {
  Value?: boolean;
  Confidence?: number;
}
export interface FaceOccluded {
  Value?: boolean;
  Confidence?: number;
}
export declare const GenderType: {
  readonly Female: "Female";
  readonly Male: "Male";
};
export type GenderType = (typeof GenderType)[keyof typeof GenderType];
export interface Gender {
  Value?: GenderType;
  Confidence?: number;
}
export interface MouthOpen {
  Value?: boolean;
  Confidence?: number;
}
export interface Mustache {
  Value?: boolean;
  Confidence?: number;
}
export interface Sunglasses {
  Value?: boolean;
  Confidence?: number;
}
export interface FaceDetail {
  BoundingBox?: BoundingBox;
  AgeRange?: AgeRange;
  Smile?: Smile;
  Eyeglasses?: Eyeglasses;
  Sunglasses?: Sunglasses;
  Gender?: Gender;
  Beard?: Beard;
  Mustache?: Mustache;
  EyesOpen?: EyeOpen;
  MouthOpen?: MouthOpen;
  Emotions?: Emotion[];
  Landmarks?: Landmark[];
  Pose?: Pose;
  Quality?: ImageQuality;
  Confidence?: number;
  FaceOccluded?: FaceOccluded;
  EyeDirection?: EyeDirection;
}
export interface CelebrityDetail {
  Urls?: string[];
  Name?: string;
  Id?: string;
  Confidence?: number;
  BoundingBox?: BoundingBox;
  Face?: FaceDetail;
  KnownGender?: KnownGender;
}
export interface CelebrityRecognition {
  Timestamp?: number;
  Celebrity?: CelebrityDetail;
}
export declare const CelebrityRecognitionSortBy: {
  readonly ID: "ID";
  readonly TIMESTAMP: "TIMESTAMP";
};
export type CelebrityRecognitionSortBy =
  (typeof CelebrityRecognitionSortBy)[keyof typeof CelebrityRecognitionSortBy];
export interface ComparedSourceImageFace {
  BoundingBox?: BoundingBox;
  Confidence?: number;
}
export declare const QualityFilter: {
  readonly AUTO: "AUTO";
  readonly HIGH: "HIGH";
  readonly LOW: "LOW";
  readonly MEDIUM: "MEDIUM";
  readonly NONE: "NONE";
};
export type QualityFilter = (typeof QualityFilter)[keyof typeof QualityFilter];
export interface Image {
  Bytes?: Uint8Array;
  S3Object?: S3Object;
}
export interface CompareFacesRequest {
  SourceImage: Image | undefined;
  TargetImage: Image | undefined;
  SimilarityThreshold?: number;
  QualityFilter?: QualityFilter;
}
export interface CompareFacesMatch {
  Similarity?: number;
  Face?: ComparedFace;
}
export declare const OrientationCorrection: {
  readonly ROTATE_0: "ROTATE_0";
  readonly ROTATE_180: "ROTATE_180";
  readonly ROTATE_270: "ROTATE_270";
  readonly ROTATE_90: "ROTATE_90";
};
export type OrientationCorrection =
  (typeof OrientationCorrection)[keyof typeof OrientationCorrection];
export interface CompareFacesResponse {
  SourceImageFace?: ComparedSourceImageFace;
  FaceMatches?: CompareFacesMatch[];
  UnmatchedFaces?: ComparedFace[];
  SourceImageOrientationCorrection?: OrientationCorrection;
  TargetImageOrientationCorrection?: OrientationCorrection;
}
export declare class ImageTooLargeException extends __BaseException {
  readonly name: "ImageTooLargeException";
  readonly $fault: "client";
  Message?: string;
  Code?: string;
  Logref?: string;
  constructor(
    opts: __ExceptionOptionType<ImageTooLargeException, __BaseException>
  );
}
export declare class InvalidImageFormatException extends __BaseException {
  readonly name: "InvalidImageFormatException";
  readonly $fault: "client";
  Message?: string;
  Code?: string;
  Logref?: string;
  constructor(
    opts: __ExceptionOptionType<InvalidImageFormatException, __BaseException>
  );
}
export declare class InvalidS3ObjectException extends __BaseException {
  readonly name: "InvalidS3ObjectException";
  readonly $fault: "client";
  Message?: string;
  Code?: string;
  Logref?: string;
  constructor(
    opts: __ExceptionOptionType<InvalidS3ObjectException, __BaseException>
  );
}
export interface ConnectedHomeSettings {
  Labels: string[] | undefined;
  MinConfidence?: number;
}
export interface ConnectedHomeSettingsForUpdate {
  Labels?: string[];
  MinConfidence?: number;
}
export declare const ContentClassifier: {
  readonly FREE_OF_ADULT_CONTENT: "FreeOfAdultContent";
  readonly FREE_OF_PERSONALLY_IDENTIFIABLE_INFORMATION: "FreeOfPersonallyIdentifiableInformation";
};
export type ContentClassifier =
  (typeof ContentClassifier)[keyof typeof ContentClassifier];
export declare const ContentModerationAggregateBy: {
  readonly SEGMENTS: "SEGMENTS";
  readonly TIMESTAMPS: "TIMESTAMPS";
};
export type ContentModerationAggregateBy =
  (typeof ContentModerationAggregateBy)[keyof typeof ContentModerationAggregateBy];
export interface ContentType {
  Confidence?: number;
  Name?: string;
}
export interface ModerationLabel {
  Confidence?: number;
  Name?: string;
  ParentName?: string;
  TaxonomyLevel?: number;
}
export interface ContentModerationDetection {
  Timestamp?: number;
  ModerationLabel?: ModerationLabel;
  StartTimestampMillis?: number;
  EndTimestampMillis?: number;
  DurationMillis?: number;
  ContentTypes?: ContentType[];
}
export declare const ContentModerationSortBy: {
  readonly NAME: "NAME";
  readonly TIMESTAMP: "TIMESTAMP";
};
export type ContentModerationSortBy =
  (typeof ContentModerationSortBy)[keyof typeof ContentModerationSortBy];
export interface OutputConfig {
  S3Bucket?: string;
  S3KeyPrefix?: string;
}
export interface CopyProjectVersionRequest {
  SourceProjectArn: string | undefined;
  SourceProjectVersionArn: string | undefined;
  DestinationProjectArn: string | undefined;
  VersionName: string | undefined;
  OutputConfig: OutputConfig | undefined;
  Tags?: Record<string, string>;
  KmsKeyId?: string;
}
export interface CopyProjectVersionResponse {
  ProjectVersionArn?: string;
}
export declare class LimitExceededException extends __BaseException {
  readonly name: "LimitExceededException";
  readonly $fault: "client";
  Message?: string;
  Code?: string;
  Logref?: string;
  constructor(
    opts: __ExceptionOptionType<LimitExceededException, __BaseException>
  );
}
export declare class ResourceInUseException extends __BaseException {
  readonly name: "ResourceInUseException";
  readonly $fault: "client";
  Message?: string;
  Code?: string;
  Logref?: string;
  constructor(
    opts: __ExceptionOptionType<ResourceInUseException, __BaseException>
  );
}
export interface CreateCollectionRequest {
  CollectionId: string | undefined;
  Tags?: Record<string, string>;
}
export interface CreateCollectionResponse {
  StatusCode?: number;
  CollectionArn?: string;
  FaceModelVersion?: string;
}
export declare class ResourceAlreadyExistsException extends __BaseException {
  readonly name: "ResourceAlreadyExistsException";
  readonly $fault: "client";
  Message?: string;
  Code?: string;
  Logref?: string;
  constructor(
    opts: __ExceptionOptionType<ResourceAlreadyExistsException, __BaseException>
  );
}
export interface DatasetSource {
  GroundTruthManifest?: GroundTruthManifest;
  DatasetArn?: string;
}
export declare const DatasetType: {
  readonly TEST: "TEST";
  readonly TRAIN: "TRAIN";
};
export type DatasetType = (typeof DatasetType)[keyof typeof DatasetType];
export interface CreateDatasetRequest {
  DatasetSource?: DatasetSource;
  DatasetType: DatasetType | undefined;
  ProjectArn: string | undefined;
}
export interface CreateDatasetResponse {
  DatasetArn?: string;
}
export interface LivenessOutputConfig {
  S3Bucket: string | undefined;
  S3KeyPrefix?: string;
}
export interface CreateFaceLivenessSessionRequestSettings {
  OutputConfig?: LivenessOutputConfig;
  AuditImagesLimit?: number;
}
export interface CreateFaceLivenessSessionRequest {
  KmsKeyId?: string;
  Settings?: CreateFaceLivenessSessionRequestSettings;
  ClientRequestToken?: string;
}
export interface CreateFaceLivenessSessionResponse {
  SessionId: string | undefined;
}
export declare const ProjectAutoUpdate: {
  readonly DISABLED: "DISABLED";
  readonly ENABLED: "ENABLED";
};
export type ProjectAutoUpdate =
  (typeof ProjectAutoUpdate)[keyof typeof ProjectAutoUpdate];
export declare const CustomizationFeature: {
  readonly CONTENT_MODERATION: "CONTENT_MODERATION";
  readonly CUSTOM_LABELS: "CUSTOM_LABELS";
};
export type CustomizationFeature =
  (typeof CustomizationFeature)[keyof typeof CustomizationFeature];
export interface CreateProjectRequest {
  ProjectName: string | undefined;
  Feature?: CustomizationFeature;
  AutoUpdate?: ProjectAutoUpdate;
}
export interface CreateProjectResponse {
  ProjectArn?: string;
}
export interface CustomizationFeatureContentModerationConfig {
  ConfidenceThreshold?: number;
}
export interface CustomizationFeatureConfig {
  ContentModeration?: CustomizationFeatureContentModerationConfig;
}
export interface TestingData {
  Assets?: Asset[];
  AutoCreate?: boolean;
}
export interface TrainingData {
  Assets?: Asset[];
}
export interface CreateProjectVersionRequest {
  ProjectArn: string | undefined;
  VersionName: string | undefined;
  OutputConfig: OutputConfig | undefined;
  TrainingData?: TrainingData;
  TestingData?: TestingData;
  Tags?: Record<string, string>;
  KmsKeyId?: string;
  VersionDescription?: string;
  FeatureConfig?: CustomizationFeatureConfig;
}
export interface CreateProjectVersionResponse {
  ProjectVersionArn?: string;
}
export interface StreamProcessorDataSharingPreference {
  OptIn: boolean | undefined;
}
export interface KinesisVideoStream {
  Arn?: string;
}
export interface StreamProcessorInput {
  KinesisVideoStream?: KinesisVideoStream;
}
export interface StreamProcessorNotificationChannel {
  SNSTopicArn: string | undefined;
}
export interface KinesisDataStream {
  Arn?: string;
}
export interface S3Destination {
  Bucket?: string;
  KeyPrefix?: string;
}
export interface StreamProcessorOutput {
  KinesisDataStream?: KinesisDataStream;
  S3Destination?: S3Destination;
}
export interface Point {
  X?: number;
  Y?: number;
}
export interface RegionOfInterest {
  BoundingBox?: BoundingBox;
  Polygon?: Point[];
}
export interface FaceSearchSettings {
  CollectionId?: string;
  FaceMatchThreshold?: number;
}
export interface StreamProcessorSettings {
  FaceSearch?: FaceSearchSettings;
  ConnectedHome?: ConnectedHomeSettings;
}
export interface CreateStreamProcessorRequest {
  Input: StreamProcessorInput | undefined;
  Output: StreamProcessorOutput | undefined;
  Name: string | undefined;
  Settings: StreamProcessorSettings | undefined;
  RoleArn: string | undefined;
  Tags?: Record<string, string>;
  NotificationChannel?: StreamProcessorNotificationChannel;
  KmsKeyId?: string;
  RegionsOfInterest?: RegionOfInterest[];
  DataSharingPreference?: StreamProcessorDataSharingPreference;
}
export interface CreateStreamProcessorResponse {
  StreamProcessorArn?: string;
}
export interface CreateUserRequest {
  CollectionId: string | undefined;
  UserId: string | undefined;
  ClientRequestToken?: string;
}
export interface CreateUserResponse {}
export interface Geometry {
  BoundingBox?: BoundingBox;
  Polygon?: Point[];
}
export interface CustomLabel {
  Name?: string;
  Confidence?: number;
  Geometry?: Geometry;
}
export interface DatasetChanges {
  GroundTruth: Uint8Array | undefined;
}
export interface DatasetStats {
  LabeledEntries?: number;
  TotalEntries?: number;
  TotalLabels?: number;
  ErrorEntries?: number;
}
export declare const DatasetStatus: {
  readonly CREATE_COMPLETE: "CREATE_COMPLETE";
  readonly CREATE_FAILED: "CREATE_FAILED";
  readonly CREATE_IN_PROGRESS: "CREATE_IN_PROGRESS";
  readonly DELETE_IN_PROGRESS: "DELETE_IN_PROGRESS";
  readonly UPDATE_COMPLETE: "UPDATE_COMPLETE";
  readonly UPDATE_FAILED: "UPDATE_FAILED";
  readonly UPDATE_IN_PROGRESS: "UPDATE_IN_PROGRESS";
};
export type DatasetStatus = (typeof DatasetStatus)[keyof typeof DatasetStatus];
export declare const DatasetStatusMessageCode: {
  readonly CLIENT_ERROR: "CLIENT_ERROR";
  readonly SERVICE_ERROR: "SERVICE_ERROR";
  readonly SUCCESS: "SUCCESS";
};
export type DatasetStatusMessageCode =
  (typeof DatasetStatusMessageCode)[keyof typeof DatasetStatusMessageCode];
export interface DatasetDescription {
  CreationTimestamp?: Date;
  LastUpdatedTimestamp?: Date;
  Status?: DatasetStatus;
  StatusMessage?: string;
  StatusMessageCode?: DatasetStatusMessageCode;
  DatasetStats?: DatasetStats;
}
export interface DatasetLabelStats {
  EntryCount?: number;
  BoundingBoxCount?: number;
}
export interface DatasetLabelDescription {
  LabelName?: string;
  LabelStats?: DatasetLabelStats;
}
export interface DatasetMetadata {
  CreationTimestamp?: Date;
  DatasetType?: DatasetType;
  DatasetArn?: string;
  Status?: DatasetStatus;
  StatusMessage?: string;
  StatusMessageCode?: DatasetStatusMessageCode;
}
export interface DeleteCollectionRequest {
  CollectionId: string | undefined;
}
export interface DeleteCollectionResponse {
  StatusCode?: number;
}
export interface DeleteDatasetRequest {
  DatasetArn: string | undefined;
}
export interface DeleteDatasetResponse {}
export interface DeleteFacesRequest {
  CollectionId: string | undefined;
  FaceIds: string[] | undefined;
}
export declare const UnsuccessfulFaceDeletionReason: {
  readonly ASSOCIATED_TO_AN_EXISTING_USER: "ASSOCIATED_TO_AN_EXISTING_USER";
  readonly FACE_NOT_FOUND: "FACE_NOT_FOUND";
};
export type UnsuccessfulFaceDeletionReason =
  (typeof UnsuccessfulFaceDeletionReason)[keyof typeof UnsuccessfulFaceDeletionReason];
export interface UnsuccessfulFaceDeletion {
  FaceId?: string;
  UserId?: string;
  Reasons?: UnsuccessfulFaceDeletionReason[];
}
export interface DeleteFacesResponse {
  DeletedFaces?: string[];
  UnsuccessfulFaceDeletions?: UnsuccessfulFaceDeletion[];
}
export interface DeleteProjectRequest {
  ProjectArn: string | undefined;
}
export declare const ProjectStatus: {
  readonly CREATED: "CREATED";
  readonly CREATING: "CREATING";
  readonly DELETING: "DELETING";
};
export type ProjectStatus = (typeof ProjectStatus)[keyof typeof ProjectStatus];
export interface DeleteProjectResponse {
  Status?: ProjectStatus;
}
export interface DeleteProjectPolicyRequest {
  ProjectArn: string | undefined;
  PolicyName: string | undefined;
  PolicyRevisionId?: string;
}
export interface DeleteProjectPolicyResponse {}
export declare class InvalidPolicyRevisionIdException extends __BaseException {
  readonly name: "InvalidPolicyRevisionIdException";
  readonly $fault: "client";
  Message?: string;
  Code?: string;
  Logref?: string;
  constructor(
    opts: __ExceptionOptionType<
      InvalidPolicyRevisionIdException,
      __BaseException
    >
  );
}
export interface DeleteProjectVersionRequest {
  ProjectVersionArn: string | undefined;
}
export declare const ProjectVersionStatus: {
  readonly COPYING_COMPLETED: "COPYING_COMPLETED";
  readonly COPYING_FAILED: "COPYING_FAILED";
  readonly COPYING_IN_PROGRESS: "COPYING_IN_PROGRESS";
  readonly DELETING: "DELETING";
  readonly DEPRECATED: "DEPRECATED";
  readonly EXPIRED: "EXPIRED";
  readonly FAILED: "FAILED";
  readonly RUNNING: "RUNNING";
  readonly STARTING: "STARTING";
  readonly STOPPED: "STOPPED";
  readonly STOPPING: "STOPPING";
  readonly TRAINING_COMPLETED: "TRAINING_COMPLETED";
  readonly TRAINING_FAILED: "TRAINING_FAILED";
  readonly TRAINING_IN_PROGRESS: "TRAINING_IN_PROGRESS";
};
export type ProjectVersionStatus =
  (typeof ProjectVersionStatus)[keyof typeof ProjectVersionStatus];
export interface DeleteProjectVersionResponse {
  Status?: ProjectVersionStatus;
}
export interface DeleteStreamProcessorRequest {
  Name: string | undefined;
}
export interface DeleteStreamProcessorResponse {}
export interface DeleteUserRequest {
  CollectionId: string | undefined;
  UserId: string | undefined;
  ClientRequestToken?: string;
}
export interface DeleteUserResponse {}
export interface DescribeCollectionRequest {
  CollectionId: string | undefined;
}
export interface DescribeCollectionResponse {
  FaceCount?: number;
  FaceModelVersion?: string;
  CollectionARN?: string;
  CreationTimestamp?: Date;
  UserCount?: number;
}
export interface DescribeDatasetRequest {
  DatasetArn: string | undefined;
}
export interface DescribeDatasetResponse {
  DatasetDescription?: DatasetDescription;
}
export interface DescribeProjectsRequest {
  NextToken?: string;
  MaxResults?: number;
  ProjectNames?: string[];
  Features?: CustomizationFeature[];
}
export interface ProjectDescription {
  ProjectArn?: string;
  CreationTimestamp?: Date;
  Status?: ProjectStatus;
  Datasets?: DatasetMetadata[];
  Feature?: CustomizationFeature;
  AutoUpdate?: ProjectAutoUpdate;
}
export interface DescribeProjectsResponse {
  ProjectDescriptions?: ProjectDescription[];
  NextToken?: string;
}
export declare class InvalidPaginationTokenException extends __BaseException {
  readonly name: "InvalidPaginationTokenException";
  readonly $fault: "client";
  Message?: string;
  Code?: string;
  Logref?: string;
  constructor(
    opts: __ExceptionOptionType<
      InvalidPaginationTokenException,
      __BaseException
    >
  );
}
export interface DescribeProjectVersionsRequest {
  ProjectArn: string | undefined;
  VersionNames?: string[];
  NextToken?: string;
  MaxResults?: number;
}
export interface Summary {
  S3Object?: S3Object;
}
export interface EvaluationResult {
  F1Score?: number;
  Summary?: Summary;
}
export interface ValidationData {
  Assets?: Asset[];
}
export interface TestingDataResult {
  Input?: TestingData;
  Output?: TestingData;
  Validation?: ValidationData;
}
export interface TrainingDataResult {
  Input?: TrainingData;
  Output?: TrainingData;
  Validation?: ValidationData;
}
export interface ProjectVersionDescription {
  ProjectVersionArn?: string;
  CreationTimestamp?: Date;
  MinInferenceUnits?: number;
  Status?: ProjectVersionStatus;
  StatusMessage?: string;
  BillableTrainingTimeInSeconds?: number;
  TrainingEndTimestamp?: Date;
  OutputConfig?: OutputConfig;
  TrainingDataResult?: TrainingDataResult;
  TestingDataResult?: TestingDataResult;
  EvaluationResult?: EvaluationResult;
  ManifestSummary?: GroundTruthManifest;
  KmsKeyId?: string;
  MaxInferenceUnits?: number;
  SourceProjectVersionArn?: string;
  VersionDescription?: string;
  Feature?: CustomizationFeature;
  BaseModelVersion?: string;
  FeatureConfig?: CustomizationFeatureConfig;
}
export interface DescribeProjectVersionsResponse {
  ProjectVersionDescriptions?: ProjectVersionDescription[];
  NextToken?: string;
}
export interface DescribeStreamProcessorRequest {
  Name: string | undefined;
}
export declare const StreamProcessorStatus: {
  readonly FAILED: "FAILED";
  readonly RUNNING: "RUNNING";
  readonly STARTING: "STARTING";
  readonly STOPPED: "STOPPED";
  readonly STOPPING: "STOPPING";
  readonly UPDATING: "UPDATING";
};
export type StreamProcessorStatus =
  (typeof StreamProcessorStatus)[keyof typeof StreamProcessorStatus];
export interface DescribeStreamProcessorResponse {
  Name?: string;
  StreamProcessorArn?: string;
  Status?: StreamProcessorStatus;
  StatusMessage?: string;
  CreationTimestamp?: Date;
  LastUpdateTimestamp?: Date;
  Input?: StreamProcessorInput;
  Output?: StreamProcessorOutput;
  RoleArn?: string;
  Settings?: StreamProcessorSettings;
  NotificationChannel?: StreamProcessorNotificationChannel;
  KmsKeyId?: string;
  RegionsOfInterest?: RegionOfInterest[];
  DataSharingPreference?: StreamProcessorDataSharingPreference;
}
export interface DetectCustomLabelsRequest {
  ProjectVersionArn: string | undefined;
  Image: Image | undefined;
  MaxResults?: number;
  MinConfidence?: number;
}
export interface DetectCustomLabelsResponse {
  CustomLabels?: CustomLabel[];
}
export declare class ResourceNotReadyException extends __BaseException {
  readonly name: "ResourceNotReadyException";
  readonly $fault: "client";
  Message?: string;
  Code?: string;
  Logref?: string;
  constructor(
    opts: __ExceptionOptionType<ResourceNotReadyException, __BaseException>
  );
}
export interface DetectFacesRequest {
  Image: Image | undefined;
  Attributes?: Attribute[];
}
export interface DetectFacesResponse {
  FaceDetails?: FaceDetail[];
  OrientationCorrection?: OrientationCorrection;
}
export interface DetectionFilter {
  MinConfidence?: number;
  MinBoundingBoxHeight?: number;
  MinBoundingBoxWidth?: number;
}
export declare const DetectLabelsFeatureName: {
  readonly GENERAL_LABELS: "GENERAL_LABELS";
  readonly IMAGE_PROPERTIES: "IMAGE_PROPERTIES";
};
export type DetectLabelsFeatureName =
  (typeof DetectLabelsFeatureName)[keyof typeof DetectLabelsFeatureName];
export interface GeneralLabelsSettings {
  LabelInclusionFilters?: string[];
  LabelExclusionFilters?: string[];
  LabelCategoryInclusionFilters?: string[];
  LabelCategoryExclusionFilters?: string[];
}
export interface DetectLabelsImagePropertiesSettings {
  MaxDominantColors?: number;
}
export interface DetectLabelsSettings {
  GeneralLabels?: GeneralLabelsSettings;
  ImageProperties?: DetectLabelsImagePropertiesSettings;
}
export interface DetectLabelsRequest {
  Image: Image | undefined;
  MaxLabels?: number;
  MinConfidence?: number;
  Features?: DetectLabelsFeatureName[];
  Settings?: DetectLabelsSettings;
}
export interface DominantColor {
  Red?: number;
  Blue?: number;
  Green?: number;
  HexCode?: string;
  CSSColor?: string;
  SimplifiedColor?: string;
  PixelPercent?: number;
}
export interface DetectLabelsImageQuality {
  Brightness?: number;
  Sharpness?: number;
  Contrast?: number;
}
export interface DetectLabelsImageBackground {
  Quality?: DetectLabelsImageQuality;
  DominantColors?: DominantColor[];
}
export interface DetectLabelsImageForeground {
  Quality?: DetectLabelsImageQuality;
  DominantColors?: DominantColor[];
}
export interface DetectLabelsImageProperties {
  Quality?: DetectLabelsImageQuality;
  DominantColors?: DominantColor[];
  Foreground?: DetectLabelsImageForeground;
  Background?: DetectLabelsImageBackground;
}
export interface LabelAlias {
  Name?: string;
}
export interface LabelCategory {
  Name?: string;
}
export interface Instance {
  BoundingBox?: BoundingBox;
  Confidence?: number;
  DominantColors?: DominantColor[];
}
export interface Parent {
  Name?: string;
}
export interface Label {
  Name?: string;
  Confidence?: number;
  Instances?: Instance[];
  Parents?: Parent[];
  Aliases?: LabelAlias[];
  Categories?: LabelCategory[];
}
export interface DetectLabelsResponse {
  Labels?: Label[];
  OrientationCorrection?: OrientationCorrection;
  LabelModelVersion?: string;
  ImageProperties?: DetectLabelsImageProperties;
}
export interface HumanLoopDataAttributes {
  ContentClassifiers?: ContentClassifier[];
}
export interface HumanLoopConfig {
  HumanLoopName: string | undefined;
  FlowDefinitionArn: string | undefined;
  DataAttributes?: HumanLoopDataAttributes;
}
export interface DetectModerationLabelsRequest {
  Image: Image | undefined;
  MinConfidence?: number;
  HumanLoopConfig?: HumanLoopConfig;
  ProjectVersion?: string;
}
export interface HumanLoopActivationOutput {
  HumanLoopArn?: string;
  HumanLoopActivationReasons?: string[];
  HumanLoopActivationConditionsEvaluationResults?: __LazyJsonString | string;
}
export interface DetectModerationLabelsResponse {
  ModerationLabels?: ModerationLabel[];
  ModerationModelVersion?: string;
  HumanLoopActivationOutput?: HumanLoopActivationOutput;
  ProjectVersion?: string;
  ContentTypes?: ContentType[];
}
export declare class HumanLoopQuotaExceededException extends __BaseException {
  readonly name: "HumanLoopQuotaExceededException";
  readonly $fault: "client";
  ResourceType?: string;
  QuotaCode?: string;
  ServiceCode?: string;
  Message?: string;
  Code?: string;
  Logref?: string;
  constructor(
    opts: __ExceptionOptionType<
      HumanLoopQuotaExceededException,
      __BaseException
    >
  );
}
export interface ProtectiveEquipmentSummarizationAttributes {
  MinConfidence: number | undefined;
  RequiredEquipmentTypes: ProtectiveEquipmentType[] | undefined;
}
export interface DetectProtectiveEquipmentRequest {
  Image: Image | undefined;
  SummarizationAttributes?: ProtectiveEquipmentSummarizationAttributes;
}
export interface ProtectiveEquipmentPerson {
  BodyParts?: ProtectiveEquipmentBodyPart[];
  BoundingBox?: BoundingBox;
  Confidence?: number;
  Id?: number;
}
export interface ProtectiveEquipmentSummary {
  PersonsWithRequiredEquipment?: number[];
  PersonsWithoutRequiredEquipment?: number[];
  PersonsIndeterminate?: number[];
}
export interface DetectProtectiveEquipmentResponse {
  ProtectiveEquipmentModelVersion?: string;
  Persons?: ProtectiveEquipmentPerson[];
  Summary?: ProtectiveEquipmentSummary;
}
export interface DetectTextFilters {
  WordFilter?: DetectionFilter;
  RegionsOfInterest?: RegionOfInterest[];
}
export interface DetectTextRequest {
  Image: Image | undefined;
  Filters?: DetectTextFilters;
}
export declare const TextTypes: {
  readonly LINE: "LINE";
  readonly WORD: "WORD";
};
export type TextTypes = (typeof TextTypes)[keyof typeof TextTypes];
export interface TextDetection {
  DetectedText?: string;
  Type?: TextTypes;
  Id?: number;
  ParentId?: number;
  Confidence?: number;
  Geometry?: Geometry;
}
export interface DetectTextResponse {
  TextDetections?: TextDetection[];
  TextModelVersion?: string;
}
export interface DisassociatedFace {
  FaceId?: string;
}
export interface DisassociateFacesRequest {
  CollectionId: string | undefined;
  UserId: string | undefined;
  ClientRequestToken?: string;
  FaceIds: string[] | undefined;
}
export declare const UnsuccessfulFaceDisassociationReason: {
  readonly ASSOCIATED_TO_A_DIFFERENT_USER: "ASSOCIATED_TO_A_DIFFERENT_USER";
  readonly FACE_NOT_FOUND: "FACE_NOT_FOUND";
};
export type UnsuccessfulFaceDisassociationReason =
  (typeof UnsuccessfulFaceDisassociationReason)[keyof typeof UnsuccessfulFaceDisassociationReason];
export interface UnsuccessfulFaceDisassociation {
  FaceId?: string;
  UserId?: string;
  Reasons?: UnsuccessfulFaceDisassociationReason[];
}
export interface DisassociateFacesResponse {
  DisassociatedFaces?: DisassociatedFace[];
  UnsuccessfulFaceDisassociations?: UnsuccessfulFaceDisassociation[];
  UserStatus?: UserStatus;
}
export interface DistributeDataset {
  Arn: string | undefined;
}
export interface DistributeDatasetEntriesRequest {
  Datasets: DistributeDataset[] | undefined;
}
export interface DistributeDatasetEntriesResponse {}
export interface Face {
  FaceId?: string;
  BoundingBox?: BoundingBox;
  ImageId?: string;
  ExternalImageId?: string;
  Confidence?: number;
  IndexFacesModelVersion?: string;
  UserId?: string;
}
export declare const FaceAttributes: {
  readonly ALL: "ALL";
  readonly DEFAULT: "DEFAULT";
};
export type FaceAttributes =
  (typeof FaceAttributes)[keyof typeof FaceAttributes];
export interface FaceDetection {
  Timestamp?: number;
  Face?: FaceDetail;
}
export interface FaceMatch {
  Similarity?: number;
  Face?: Face;
}
export interface FaceRecord {
  Face?: Face;
  FaceDetail?: FaceDetail;
}
export declare const FaceSearchSortBy: {
  readonly INDEX: "INDEX";
  readonly TIMESTAMP: "TIMESTAMP";
};
export type FaceSearchSortBy =
  (typeof FaceSearchSortBy)[keyof typeof FaceSearchSortBy];
export interface GetCelebrityInfoRequest {
  Id: string | undefined;
}
export interface GetCelebrityInfoResponse {
  Urls?: string[];
  Name?: string;
  KnownGender?: KnownGender;
}
export interface GetCelebrityRecognitionRequest {
  JobId: string | undefined;
  MaxResults?: number;
  NextToken?: string;
  SortBy?: CelebrityRecognitionSortBy;
}
export declare const VideoJobStatus: {
  readonly FAILED: "FAILED";
  readonly IN_PROGRESS: "IN_PROGRESS";
  readonly SUCCEEDED: "SUCCEEDED";
};
export type VideoJobStatus =
  (typeof VideoJobStatus)[keyof typeof VideoJobStatus];
export interface Video {
  S3Object?: S3Object;
}
export declare const VideoColorRange: {
  readonly FULL: "FULL";
  readonly LIMITED: "LIMITED";
};
export type VideoColorRange =
  (typeof VideoColorRange)[keyof typeof VideoColorRange];
export interface VideoMetadata {
  Codec?: string;
  DurationMillis?: number;
  Format?: string;
  FrameRate?: number;
  FrameHeight?: number;
  FrameWidth?: number;
  ColorRange?: VideoColorRange;
}
export interface GetCelebrityRecognitionResponse {
  JobStatus?: VideoJobStatus;
  StatusMessage?: string;
  VideoMetadata?: VideoMetadata;
  NextToken?: string;
  Celebrities?: CelebrityRecognition[];
  JobId?: string;
  Video?: Video;
  JobTag?: string;
}
export interface GetContentModerationRequest {
  JobId: string | undefined;
  MaxResults?: number;
  NextToken?: string;
  SortBy?: ContentModerationSortBy;
  AggregateBy?: ContentModerationAggregateBy;
}
export interface GetContentModerationRequestMetadata {
  SortBy?: ContentModerationSortBy;
  AggregateBy?: ContentModerationAggregateBy;
}
export interface GetContentModerationResponse {
  JobStatus?: VideoJobStatus;
  StatusMessage?: string;
  VideoMetadata?: VideoMetadata;
  ModerationLabels?: ContentModerationDetection[];
  NextToken?: string;
  ModerationModelVersion?: string;
  JobId?: string;
  Video?: Video;
  JobTag?: string;
  GetRequestMetadata?: GetContentModerationRequestMetadata;
}
export interface GetFaceDetectionRequest {
  JobId: string | undefined;
  MaxResults?: number;
  NextToken?: string;
}
export interface GetFaceDetectionResponse {
  JobStatus?: VideoJobStatus;
  StatusMessage?: string;
  VideoMetadata?: VideoMetadata;
  NextToken?: string;
  Faces?: FaceDetection[];
  JobId?: string;
  Video?: Video;
  JobTag?: string;
}
export interface GetFaceLivenessSessionResultsRequest {
  SessionId: string | undefined;
}
export declare const LivenessSessionStatus: {
  readonly CREATED: "CREATED";
  readonly EXPIRED: "EXPIRED";
  readonly FAILED: "FAILED";
  readonly IN_PROGRESS: "IN_PROGRESS";
  readonly SUCCEEDED: "SUCCEEDED";
};
export type LivenessSessionStatus =
  (typeof LivenessSessionStatus)[keyof typeof LivenessSessionStatus];
export interface GetFaceLivenessSessionResultsResponse {
  SessionId: string | undefined;
  Status: LivenessSessionStatus | undefined;
  Confidence?: number;
  ReferenceImage?: AuditImage;
  AuditImages?: AuditImage[];
}
export declare class SessionNotFoundException extends __BaseException {
  readonly name: "SessionNotFoundException";
  readonly $fault: "client";
  Message?: string;
  Code?: string;
  Logref?: string;
  constructor(
    opts: __ExceptionOptionType<SessionNotFoundException, __BaseException>
  );
}
export interface GetFaceSearchRequest {
  JobId: string | undefined;
  MaxResults?: number;
  NextToken?: string;
  SortBy?: FaceSearchSortBy;
}
export interface PersonDetail {
  Index?: number;
  BoundingBox?: BoundingBox;
  Face?: FaceDetail;
}
export interface PersonMatch {
  Timestamp?: number;
  Person?: PersonDetail;
  FaceMatches?: FaceMatch[];
}
export interface GetFaceSearchResponse {
  JobStatus?: VideoJobStatus;
  StatusMessage?: string;
  NextToken?: string;
  VideoMetadata?: VideoMetadata;
  Persons?: PersonMatch[];
  JobId?: string;
  Video?: Video;
  JobTag?: string;
}
export declare const LabelDetectionAggregateBy: {
  readonly SEGMENTS: "SEGMENTS";
  readonly TIMESTAMPS: "TIMESTAMPS";
};
export type LabelDetectionAggregateBy =
  (typeof LabelDetectionAggregateBy)[keyof typeof LabelDetectionAggregateBy];
export declare const LabelDetectionSortBy: {
  readonly NAME: "NAME";
  readonly TIMESTAMP: "TIMESTAMP";
};
export type LabelDetectionSortBy =
  (typeof LabelDetectionSortBy)[keyof typeof LabelDetectionSortBy];
export interface GetLabelDetectionRequest {
  JobId: string | undefined;
  MaxResults?: number;
  NextToken?: string;
  SortBy?: LabelDetectionSortBy;
  AggregateBy?: LabelDetectionAggregateBy;
}
export interface GetLabelDetectionRequestMetadata {
  SortBy?: LabelDetectionSortBy;
  AggregateBy?: LabelDetectionAggregateBy;
}
export interface LabelDetection {
  Timestamp?: number;
  Label?: Label;
  StartTimestampMillis?: number;
  EndTimestampMillis?: number;
  DurationMillis?: number;
}
export interface GetLabelDetectionResponse {
  JobStatus?: VideoJobStatus;
  StatusMessage?: string;
  VideoMetadata?: VideoMetadata;
  NextToken?: string;
  Labels?: LabelDetection[];
  LabelModelVersion?: string;
  JobId?: string;
  Video?: Video;
  JobTag?: string;
  GetRequestMetadata?: GetLabelDetectionRequestMetadata;
}
export interface GetMediaAnalysisJobRequest {
  JobId: string | undefined;
}
export declare const MediaAnalysisJobFailureCode: {
  readonly ACCESS_DENIED: "ACCESS_DENIED";
  readonly INTERNAL_ERROR: "INTERNAL_ERROR";
  readonly INVALID_KMS_KEY: "INVALID_KMS_KEY";
  readonly INVALID_MANIFEST: "INVALID_MANIFEST";
  readonly INVALID_OUTPUT_CONFIG: "INVALID_OUTPUT_CONFIG";
  readonly INVALID_S3_OBJECT: "INVALID_S3_OBJECT";
  readonly RESOURCE_NOT_FOUND: "RESOURCE_NOT_FOUND";
  readonly RESOURCE_NOT_READY: "RESOURCE_NOT_READY";
  readonly THROTTLED: "THROTTLED";
};
export type MediaAnalysisJobFailureCode =
  (typeof MediaAnalysisJobFailureCode)[keyof typeof MediaAnalysisJobFailureCode];
export interface MediaAnalysisJobFailureDetails {
  Code?: MediaAnalysisJobFailureCode;
  Message?: string;
}
export interface MediaAnalysisInput {
  S3Object: S3Object | undefined;
}
export interface MediaAnalysisManifestSummary {
  S3Object?: S3Object;
}
export interface MediaAnalysisDetectModerationLabelsConfig {
  MinConfidence?: number;
  ProjectVersion?: string;
}
export interface MediaAnalysisOperationsConfig {
  DetectModerationLabels?: MediaAnalysisDetectModerationLabelsConfig;
}
export interface MediaAnalysisOutputConfig {
  S3Bucket: string | undefined;
  S3KeyPrefix?: string;
}
export interface MediaAnalysisModelVersions {
  Moderation?: string;
}
export interface MediaAnalysisResults {
  S3Object?: S3Object;
  ModelVersions?: MediaAnalysisModelVersions;
}
export declare const MediaAnalysisJobStatus: {
  readonly CREATED: "CREATED";
  readonly FAILED: "FAILED";
  readonly IN_PROGRESS: "IN_PROGRESS";
  readonly QUEUED: "QUEUED";
  readonly SUCCEEDED: "SUCCEEDED";
};
export type MediaAnalysisJobStatus =
  (typeof MediaAnalysisJobStatus)[keyof typeof MediaAnalysisJobStatus];
export interface GetMediaAnalysisJobResponse {
  JobId: string | undefined;
  JobName?: string;
  OperationsConfig: MediaAnalysisOperationsConfig | undefined;
  Status: MediaAnalysisJobStatus | undefined;
  FailureDetails?: MediaAnalysisJobFailureDetails;
  CreationTimestamp: Date | undefined;
  CompletionTimestamp?: Date;
  Input: MediaAnalysisInput | undefined;
  OutputConfig: MediaAnalysisOutputConfig | undefined;
  KmsKeyId?: string;
  Results?: MediaAnalysisResults;
  ManifestSummary?: MediaAnalysisManifestSummary;
}
export declare const PersonTrackingSortBy: {
  readonly INDEX: "INDEX";
  readonly TIMESTAMP: "TIMESTAMP";
};
export type PersonTrackingSortBy =
  (typeof PersonTrackingSortBy)[keyof typeof PersonTrackingSortBy];
export interface GetPersonTrackingRequest {
  JobId: string | undefined;
  MaxResults?: number;
  NextToken?: string;
  SortBy?: PersonTrackingSortBy;
}
export interface PersonDetection {
  Timestamp?: number;
  Person?: PersonDetail;
}
export interface GetPersonTrackingResponse {
  JobStatus?: VideoJobStatus;
  StatusMessage?: string;
  VideoMetadata?: VideoMetadata;
  NextToken?: string;
  Persons?: PersonDetection[];
  JobId?: string;
  Video?: Video;
  JobTag?: string;
}
export interface GetSegmentDetectionRequest {
  JobId: string | undefined;
  MaxResults?: number;
  NextToken?: string;
}
export interface ShotSegment {
  Index?: number;
  Confidence?: number;
}
export declare const TechnicalCueType: {
  readonly BLACK_FRAMES: "BlackFrames";
  readonly COLOR_BARS: "ColorBars";
  readonly CONTENT: "Content";
  readonly END_CREDITS: "EndCredits";
  readonly OPENING_CREDITS: "OpeningCredits";
  readonly SLATE: "Slate";
  readonly STUDIO_LOGO: "StudioLogo";
};
export type TechnicalCueType =
  (typeof TechnicalCueType)[keyof typeof TechnicalCueType];
export interface TechnicalCueSegment {
  Type?: TechnicalCueType;
  Confidence?: number;
}
export declare const SegmentType: {
  readonly SHOT: "SHOT";
  readonly TECHNICAL_CUE: "TECHNICAL_CUE";
};
export type SegmentType = (typeof SegmentType)[keyof typeof SegmentType];
export interface SegmentDetection {
  Type?: SegmentType;
  StartTimestampMillis?: number;
  EndTimestampMillis?: number;
  DurationMillis?: number;
  StartTimecodeSMPTE?: string;
  EndTimecodeSMPTE?: string;
  DurationSMPTE?: string;
  TechnicalCueSegment?: TechnicalCueSegment;
  ShotSegment?: ShotSegment;
  StartFrameNumber?: number;
  EndFrameNumber?: number;
  DurationFrames?: number;
}
export interface SegmentTypeInfo {
  Type?: SegmentType;
  ModelVersion?: string;
}
export interface GetSegmentDetectionResponse {
  JobStatus?: VideoJobStatus;
  StatusMessage?: string;
  VideoMetadata?: VideoMetadata[];
  AudioMetadata?: AudioMetadata[];
  NextToken?: string;
  Segments?: SegmentDetection[];
  SelectedSegmentTypes?: SegmentTypeInfo[];
  JobId?: string;
  Video?: Video;
  JobTag?: string;
}
export interface GetTextDetectionRequest {
  JobId: string | undefined;
  MaxResults?: number;
  NextToken?: string;
}
export interface TextDetectionResult {
  Timestamp?: number;
  TextDetection?: TextDetection;
}
export interface GetTextDetectionResponse {
  JobStatus?: VideoJobStatus;
  StatusMessage?: string;
  VideoMetadata?: VideoMetadata;
  TextDetections?: TextDetectionResult[];
  NextToken?: string;
  TextModelVersion?: string;
  JobId?: string;
  Video?: Video;
  JobTag?: string;
}
export interface IndexFacesRequest {
  CollectionId: string | undefined;
  Image: Image | undefined;
  ExternalImageId?: string;
  DetectionAttributes?: Attribute[];
  MaxFaces?: number;
  QualityFilter?: QualityFilter;
}
export declare const Reason: {
  readonly EXCEEDS_MAX_FACES: "EXCEEDS_MAX_FACES";
  readonly EXTREME_POSE: "EXTREME_POSE";
  readonly LOW_BRIGHTNESS: "LOW_BRIGHTNESS";
  readonly LOW_CONFIDENCE: "LOW_CONFIDENCE";
  readonly LOW_FACE_QUALITY: "LOW_FACE_QUALITY";
  readonly LOW_SHARPNESS: "LOW_SHARPNESS";
  readonly SMALL_BOUNDING_BOX: "SMALL_BOUNDING_BOX";
};
export type Reason = (typeof Reason)[keyof typeof Reason];
export interface UnindexedFace {
  Reasons?: Reason[];
  FaceDetail?: FaceDetail;
}
export interface IndexFacesResponse {
  FaceRecords?: FaceRecord[];
  OrientationCorrection?: OrientationCorrection;
  FaceModelVersion?: string;
  UnindexedFaces?: UnindexedFace[];
}
export declare class InvalidManifestException extends __BaseException {
  readonly name: "InvalidManifestException";
  readonly $fault: "client";
  Message?: string;
  Code?: string;
  Logref?: string;
  constructor(
    opts: __ExceptionOptionType<InvalidManifestException, __BaseException>
  );
}
export interface KinesisVideoStreamStartSelector {
  ProducerTimestamp?: number;
  FragmentNumber?: string;
}
export declare const LabelDetectionFeatureName: {
  readonly GENERAL_LABELS: "GENERAL_LABELS";
};
export type LabelDetectionFeatureName =
  (typeof LabelDetectionFeatureName)[keyof typeof LabelDetectionFeatureName];
export interface LabelDetectionSettings {
  GeneralLabels?: GeneralLabelsSettings;
}
export interface ListCollectionsRequest {
  NextToken?: string;
  MaxResults?: number;
}
export interface ListCollectionsResponse {
  CollectionIds?: string[];
  NextToken?: string;
  FaceModelVersions?: string[];
}
export interface ListDatasetEntriesRequest {
  DatasetArn: string | undefined;
  ContainsLabels?: string[];
  Labeled?: boolean;
  SourceRefContains?: string;
  HasErrors?: boolean;
  NextToken?: string;
  MaxResults?: number;
}
export interface ListDatasetEntriesResponse {
  DatasetEntries?: string[];
  NextToken?: string;
}
export interface ListDatasetLabelsRequest {
  DatasetArn: string | undefined;
  NextToken?: string;
  MaxResults?: number;
}
export interface ListDatasetLabelsResponse {
  DatasetLabelDescriptions?: DatasetLabelDescription[];
  NextToken?: string;
}
export interface ListFacesRequest {
  CollectionId: string | undefined;
  NextToken?: string;
  MaxResults?: number;
  UserId?: string;
  FaceIds?: string[];
}
export interface ListFacesResponse {
  Faces?: Face[];
  NextToken?: string;
  FaceModelVersion?: string;
}
export interface ListMediaAnalysisJobsRequest {
  NextToken?: string;
  MaxResults?: number;
}
export interface MediaAnalysisJobDescription {
  JobId: string | undefined;
  JobName?: string;
  OperationsConfig: MediaAnalysisOperationsConfig | undefined;
  Status: MediaAnalysisJobStatus | undefined;
  FailureDetails?: MediaAnalysisJobFailureDetails;
  CreationTimestamp: Date | undefined;
  CompletionTimestamp?: Date;
  Input: MediaAnalysisInput | undefined;
  OutputConfig: MediaAnalysisOutputConfig | undefined;
  KmsKeyId?: string;
  Results?: MediaAnalysisResults;
  ManifestSummary?: MediaAnalysisManifestSummary;
}
export interface ListMediaAnalysisJobsResponse {
  NextToken?: string;
  MediaAnalysisJobs: MediaAnalysisJobDescription[] | undefined;
}
export interface ListProjectPoliciesRequest {
  ProjectArn: string | undefined;
  NextToken?: string;
  MaxResults?: number;
}
export interface ProjectPolicy {
  ProjectArn?: string;
  PolicyName?: string;
  PolicyRevisionId?: string;
  PolicyDocument?: string;
  CreationTimestamp?: Date;
  LastUpdatedTimestamp?: Date;
}
export interface ListProjectPoliciesResponse {
  ProjectPolicies?: ProjectPolicy[];
  NextToken?: string;
}
export interface ListStreamProcessorsRequest {
  NextToken?: string;
  MaxResults?: number;
}
export interface StreamProcessor {
  Name?: string;
  Status?: StreamProcessorStatus;
}
export interface ListStreamProcessorsResponse {
  NextToken?: string;
  StreamProcessors?: StreamProcessor[];
}
export interface ListTagsForResourceRequest {
  ResourceArn: string | undefined;
}
export interface ListTagsForResourceResponse {
  Tags?: Record<string, string>;
}
export interface ListUsersRequest {
  CollectionId: string | undefined;
  MaxResults?: number;
  NextToken?: string;
}
export interface User {
  UserId?: string;
  UserStatus?: UserStatus;
}
export interface ListUsersResponse {
  Users?: User[];
  NextToken?: string;
}
export declare class MalformedPolicyDocumentException extends __BaseException {
  readonly name: "MalformedPolicyDocumentException";
  readonly $fault: "client";
  Message?: string;
  Code?: string;
  Logref?: string;
  constructor(
    opts: __ExceptionOptionType<
      MalformedPolicyDocumentException,
      __BaseException
    >
  );
}
export declare const AuditImageFilterSensitiveLog: (obj: AuditImage) => any;
export declare const GetFaceLivenessSessionResultsResponseFilterSensitiveLog: (
  obj: GetFaceLivenessSessionResultsResponse
) => any;
